@@ -26,6 +26,7 @@ from gns3converter.models import MODEL_TRANSFORM
 from gns3converter.node import Node
 from gns3converter.interfaces import INTERFACE_RE
 from gns3converter.topology import LegacyTopology
+from gns3converter.utils import fix_path
 
 
 class Converter():
@@ -424,7 +425,7 @@ class Converter():
         """
         Generate the shapes for the topology
 
-        :param shapes: A dict of converted shapes from the old topology
+        :param dict shapes: A dict of converted shapes from the old topology
         :return: dict containing two lists (ellipse, rectangle)
         :rtype: dict
         """
@@ -444,7 +445,7 @@ class Converter():
         """
         Generate the notes list
 
-        :param notes: A dict of converted notes from the old topology
+        :param dict notes: A dict of converted notes from the old topology
         :return: List of notes for the the topology
         :rtype: list
         """
@@ -459,6 +460,13 @@ class Converter():
         return new_notes
 
     def generate_images(self, pixmaps):
+        """
+        Generate the images list and store the images to copy
+
+        :param dict pixmaps: A dict of converted pixmaps from the old topology
+        :return: A list of images
+        :rtype: list
+        """
         new_images = []
 
         for image in pixmaps:
@@ -468,7 +476,7 @@ class Converter():
                     path = os.path.join('images',
                                         os.path.basename(
                                             pixmaps[image][img_item]))
-                    tmp_image['path'] = path
+                    tmp_image['path'] = fix_path(path)
                     self.images.append(pixmaps[image][img_item])
                 else:
                     tmp_image[img_item] = pixmaps[image][img_item]
